package com.ruoyi.hezhi.mapper;

import com.ruoyi.hezhi.domain.TbEvaluateAgencyClass;

import java.util.List;
import java.util.Map;

/**
 * 评价机构分类Mapper接口
 *
 * @author ruoyi
 * @date 2024-10-23
 */
public interface TbEvaluateAgencyClassMapper
{
    /**
     * 查询评价机构分类
     *
     * @param evaluateAgencyClassId 评价机构分类主键
     * @return 评价机构分类
     */
    public TbEvaluateAgencyClass selectTbEvaluateAgencyClassByEvaluateAgencyClassId(Long evaluateAgencyClassId);

    /**
     * 查询评价机构分类列表
     *
     * @param tbEvaluateAgencyClass 评价机构分类
     * @return 评价机构分类集合
     */
    public List<TbEvaluateAgencyClass> selectTbEvaluateAgencyClassList(TbEvaluateAgencyClass tbEvaluateAgencyClass);

    /**
     * 新增评价机构分类
     *
     * @param tbEvaluateAgencyClass 评价机构分类
     * @return 结果
     */
    public int insertTbEvaluateAgencyClass(TbEvaluateAgencyClass tbEvaluateAgencyClass);

    /**
     * 修改评价机构分类
     *
     * @param tbEvaluateAgencyClass 评价机构分类
     * @return 结果
     */
    public int updateTbEvaluateAgencyClass(TbEvaluateAgencyClass tbEvaluateAgencyClass);

    /**
     * 删除评价机构分类
     *
     * @param evaluateAgencyClassId 评价机构分类主键
     * @return 结果
     */
    public int deleteTbEvaluateAgencyClassByEvaluateAgencyClassId(Long evaluateAgencyClassId);

    /**
     * 批量删除评价机构分类
     *
     * @param evaluateAgencyClassIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteTbEvaluateAgencyClassByEvaluateAgencyClassIds(Long[] evaluateAgencyClassIds);

    /**
     * 评价机构分类列表
     *
     * @param params 参数
     * @return 评价机构分类列表
     */
    public List<Map<String, Object>> getEvaluateAgencyClassMapList(Map<String, Object> params);
}
